--[[

**************************************************************************
* TankadinReminder
* by evil.oz
*
* v2.01
*************************************************************************

v2.01
-----
addon now correctly recognizes non-own bok as other's buff

v2.0
-----
total rewrite, specific to protection paladins (renamed from PalaReminder to TankadinReminder)
uses icons, no more text
mainly sacred shield monitor, but also basic buff check

v1.76
-----
onload error fix

v1.75
-----
toc update


v1.74
-----
toc update
total rework of event handling (fix seal detection)
added blessing check


v1.73
-----
toc update
4.01 stuff

v1.71
-----
toc update

v1.7
----
no more spam (aura/fury) when u are resting (clearly out of combat)

v1.6
----
added seal support
code optimization and cleanup


Addon that warns fellow paladins about the following: 

you have crusader aura when entering in combat unmounted
you have no aura when buffs changed
you dont have righteous fury and u are probably in tanking gear (only in group)
you dont have a seal when engaging melee


]]--
         
 



-- #########################################################################################################
-- onload handler and events
-- #########################################################################################################
function TankadinReminder_OnLoad(this)

 	local cls, class = UnitClass("player");

	if (class == "PALADIN") then  
			local events={}
			
			function  events:PLAYER_ENTERING_WORLD()
				TankadinReminder_CheckSpec()
			end
			     
			function events:ACTIVE_TALENT_GROUP_CHANGED()
				TankadinReminder_CheckSpec()			
			end
			
			function events:VARIABLES_LOADED()
				DEFAULT_CHAT_FRAME:AddMessage("TankadinReminder loaded sucessful", 1.0, 1.0, 0.0);
				
				
				TankadinReminder_FurySpell,_, TankadinReminder_FuryIcon = GetSpellInfo(25780)
				TankadinReminder_SacredSpell,_, TankadinReminder_SacredIcon = GetSpellInfo(20925)	
				TankadinReminder_HammerSpell,_, TankadinReminder_HammerIcon = GetSpellInfo(88263)	
				TankadinReminder_BokSpell,_, TankadinReminder_BokIcon = GetSpellInfo(20217)
				TankadinReminder_BomSpell,_, TankadinReminder_BomIcon = GetSpellInfo(19740)
				_,_,TankadinReminder_SealIcon = GetSpellInfo(31801)
				TankadinReminder_MotwSpell  = GetSpellInfo(1126)
				TankadinReminder_EmbraceSpell = GetSpellInfo(90363)
				TankadinReminder_LegacySpell = GetSpellInfo(115921)
				TankadinReminder_BlowsSpell = GetSpellInfo(115798)	
					
				
				TankadinReminderWeakTexture:SetTexture(TankadinReminder_HammerIcon)
				TankadinReminderShieldTexture:SetTexture(TankadinReminder_SacredIcon)
				TankadinReminderFuryTexture:SetTexture(TankadinReminder_FuryIcon)
				TankadinReminderBokTexture:SetTexture(TankadinReminder_BokIcon)
				TankadinReminderBomTexture:SetTexture(TankadinReminder_BomIcon)
				TankadinReminderSealTexture:SetTexture(TankadinReminder_SealIcon)
				
				TankadinReminder.Enabled = false
				TankadinReminder_CheckSpec()
				TankadinReminder_Check()
			end
			
			function events:PLAYER_REGEN_ENABLED()
				if TankadinReminder.Enabled then
			  	TankadinReminder:Hide()
				end					
			end
	  
			function events:PLAYER_REGEN_DISABLED()            --entering combat
				if TankadinReminder.Enabled then
			  	TankadinReminder:Show()
					TankadinReminder_Check()
				end
			end
	
	    function events:UNIT_AURA(unit)                         --buffs changed
	    	if TankadinReminder.Enabled then
	    		TankadinReminder_Check()
	    	end
			end
	
	
			-- activate events (cryptic blizz crap)
			this:SetScript("OnEvent", 	function(self, event, ...)
			 							events[event](self, ...); 
									end
							);
			for k, v in pairs(events) do
				this:RegisterEvent(k);
			end

	else 
		DEFAULT_CHAT_FRAME:AddMessage("TankadinReminder disabled, not a paladin", 1.0, 1.0, 0.0);
	end



end



-- #########################################################################################################
-- check functions
-- #########################################################################################################
function TankadinReminder_Check()



	if UnitName("target") and not UnitIsDead("target") and not IsMounted() and not UnitInVehicle("player") then
	
	
		local own=TankadinReminder_OwnBuffs()
		local others=TankadinReminder_OthersBuffs()	 
	
		if others[TankadinReminder_MotwSpell] or others[TankadinReminder_EmbraceSpell] or others[TankadinReminder_LegacySpell] or others[TankadinReminder_BokSpell] then
			-- we have others buff, we need bom
			if own[TankadinReminder_BomSpell] then
				TankadinReminderHide("Bom")
				TankadinReminderHide("Bok")
			else
			  TankadinReminderShow("Bom")
				TankadinReminderHide("Bok")
			end
		else
			--need bok
			if own[TankadinReminder_BokSpell] then
				TankadinReminderHide("Bom")
				TankadinReminderHide("Bok")
			else
			  TankadinReminderShow("Bok")
				TankadinReminderHide("Bom")
			end
		end
		
		if own[TankadinReminder_FurySpell] then  
			TankadinReminderHide("Fury")
		else
		  TankadinReminderShow("Fury")
		end
		
		if own[TankadinReminder_SacredSpell] then
			TankadinReminderHide("Shield")
		else
		  TankadinReminderShow("Shield")
		end
		
		if UnitDebuff("target",TankadinReminder_BlowsSpell) then
			TankadinReminderHide("Weak")
		else
			TankadinReminderShow("Weak")				  
		end
		
		if GetShapeshiftForm()==0 then
		  TankadinReminderShow("Seal")
		else
		  TankadinReminderHide("Seal")
		end		
	else
		TankadinReminderHide("Shield")
		TankadinReminderHide("Weak")
		TankadinReminderHide("Fury")
		TankadinReminderHide("Bom")
		TankadinReminderHide("Bok")
		TankadinReminderHide("Seal")
	end
		
end

function TankadinReminderShow(o)

	o=getglobal("TankadinReminder"..o)
	
	o:Show()
	o:SetWidth(48)

end

function TankadinReminderHide(o)

	o=getglobal("TankadinReminder"..o)
	
	o:Hide()
	o:SetWidth(1)

end


function TankadinReminder_CheckSpec()
	if GetSpecialization() and GetSpecializationInfo(GetSpecialization()) == 66 then
		TankadinReminder.Enabled = true
		DEFAULT_CHAT_FRAME:AddMessage("TankadinReminder ENABLED, paladin is protection", 1.0, 1.0, 0.0);
	else
		TankadinReminder.Enabled = false
		DEFAULT_CHAT_FRAME:AddMessage("TankadinReminder DISABLED, paladin is not protection", 1.0, 1.0, 0.0);
	end	
end
				
function TankadinReminder_OwnBuffs()

	local buffs = {}
	local i =  1
	
	local name, _, _, _, _, _, _, unitCaster = UnitAura("player", i)
	
	while (name ~= nil) do
	  if unitCaster == "player" then 
			buffs[name] = "FOUND"
		end
		
		i = i + 1;
		name, _, _, _, _, _, _, unitCaster, spellId = UnitAura("player", i)
	end

	return  buffs

end

function TankadinReminder_OthersBuffs()

local buffs = {}
	local i =  1
	
	local name, _, _, _, _, _, _, unitCaster = UnitAura("player", i)
	
	while (name ~= nil) do
	  if unitCaster ~= "player" then 
			buffs[name] = "FOUND"
		end
		
		i = i + 1;
		name, _, _, _, _, _, _, unitCaster, spellId = UnitAura("player", i)
	end

	return  buffs

end


function TankadinReminder_TargetBuffs()

	local i,x =  1,"";

	while (UnitDebuff("target",i) ~= nil) do
		x = x .. UnitDebuff("target",i) .. " ";
		i = i + 1;
	end

	return  x, i-1

end


-- #########################################################################################################
-- misc service functions
-- #########################################################################################################


function TankadinReminder_Message(msg)
	UIErrorsFrame:AddMessage(msg, 0, 1.0, 1.0, 1.0, 1);
end


